ScreenInfo class

Constructors

ScreenInfo({required double width, required double height, required double pixelRatio, required OrientationType orientation, required DeviceType deviceType, required ScreenSize screenSize, Breakpoint? currentBreakpoint, required EdgeInsets safeAreaPadding, required TextScaler textScaler, required Brightness brightness, required bool isTabletLayout, required bool isMobileLayout, required bool isDesktopLayout})
const
ScreenInfo.fromContext(BuildContext context)
factory

Properties

aspectRatio double
no setter
brightness Brightness
final
currentBreakpoint Breakpoint?
final
deviceType DeviceType
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
isDesktopLayout bool
final
isLandscape bool
no setter
isMobileLayout bool
final
isPortrait bool
no setter
isTabletLayout bool
final
orientation OrientationType
final
pixelRatio double
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeAreaPadding EdgeInsets
final
screenSize ScreenSize
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
textScaler TextScaler
final
width double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited