ResponsiveConfig class
Constructors
-
ResponsiveConfig({List<
Breakpoint> breakpoints = Breakpoint.defaults, bool enableAdaptiveLayout = true, bool enableOrientationChanges = true, bool enableDensityScaling = true, double baseFontSize = 16.0, double baseSpacing = 8.0, Map<String, dynamic> ? customSettings}) -
const
Properties
- baseFontSize → double
-
final
- baseSpacing → double
-
final
-
breakpoints
→ List<
Breakpoint> -
final
-
customSettings
→ Map<
String, dynamic> ? -
final
- enableAdaptiveLayout → bool
-
final
- enableDensityScaling → bool
-
final
- enableOrientationChanges → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{List< Breakpoint> ? breakpoints, bool? enableAdaptiveLayout, bool? enableOrientationChanges, bool? enableDensityScaling, double? baseFontSize, double? baseSpacing, Map<String, dynamic> ? customSettings}) → ResponsiveConfig -
getBreakpointForWidth(
double width) → Breakpoint? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultConfig → const ResponsiveConfig